pub struct IsoWeek { /* private fields */ }Expand description
An ISO 8601 week date: an ISO year and a week number in 1..=53.
The ISO year can differ from the calendar year for the first days of
January and the last days of December (e.g. 2021-01-01 is ISO week
2020-W53).
Implementations
Sourceimpl IsoWeek
impl IsoWeek
Sourcepub fn monday(self) -> Result<Date>
pub fn monday(self) -> Result<Date>
The Monday that starts this week, as a calendar date.
The resulting date lives in the ISO year (which may differ from the calendar year at the boundaries).
Sourcepub const fn first_weekday(self) -> Weekday
pub const fn first_weekday(self) -> Weekday
The weekday of the Monday of this week (always the week’s first day).